==> haskell-rio-0.1.9.2-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rio
version: 0.1.9.2
id: rio-0.1.9.2-HOQBV5R8QtgBCwMNGMKCe
key: rio-0.1.9.2-HOQBV5R8QtgBCwMNGMKCe
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/rio#readme
synopsis: A standard library for Haskell
description:
    See README and Haddocks at <https://www.stackage.org/package/rio>
category: Control
abi: 547c3391e01290ae442c0fede09f2467
exposed: True
exposed-modules:
    RIO RIO.ByteString RIO.ByteString.Lazy RIO.ByteString.Lazy.Partial
    RIO.ByteString.Partial RIO.Char RIO.Char.Partial RIO.Deque
    RIO.Directory RIO.File RIO.FilePath RIO.HashMap RIO.HashMap.Partial
    RIO.HashSet RIO.List RIO.List.Partial RIO.Map RIO.Map.Partial
    RIO.Map.Unchecked RIO.Partial RIO.Prelude RIO.Prelude.Simple
    RIO.Prelude.Types RIO.Process RIO.Seq RIO.Set RIO.Set.Partial
    RIO.Set.Unchecked RIO.State RIO.Text RIO.Text.Lazy
    RIO.Text.Lazy.Partial RIO.Text.Partial RIO.Time RIO.Vector
    RIO.Vector.Boxed RIO.Vector.Boxed.Partial RIO.Vector.Boxed.Unsafe
    RIO.Vector.Partial RIO.Vector.Storable RIO.Vector.Storable.Partial
    RIO.Vector.Storable.Unsafe RIO.Vector.Unboxed
    RIO.Vector.Unboxed.Partial RIO.Vector.Unboxed.Unsafe
    RIO.Vector.Unsafe RIO.Writer
hidden-modules: RIO.Prelude.Display RIO.Prelude.Exit
                RIO.Prelude.Extra RIO.Prelude.IO RIO.Prelude.Lens
                RIO.Prelude.Logger RIO.Prelude.Reexports RIO.Prelude.Renames
                RIO.Prelude.RIO RIO.Prelude.Text RIO.Prelude.Trace RIO.Prelude.URef
import-dirs: /usr/lib/ghc-8.6.5/site-local/rio-0.1.9.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/rio-0.1.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/rio-0.1.9.2
hs-libraries: HSrio-0.1.9.2-HOQBV5R8QtgBCwMNGMKCe
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    deepseq-1.4.4.0 directory-1.3.3.0
    exceptions-0.10.2-EJs0RkZsum56ksbfDqbl1F filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS mtl-2.2.2
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b process-1.6.5.0
    text-1.2.3.1 time-1.8.0.2
    typed-process-0.2.4.0-AKSwx7bfrQWHZVrpHcUgqK unix-2.7.2.2
    unliftio-0.2.10-HW0gokGkQoCKqTJvkCyidt
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-FCaPs5fnhYpFgvItTiMoQE
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-rio/html/rio.haddock
haddock-html: /usr/share/doc/haskell-rio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-0.1.9.2-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rio
version: 0.1.9.2
id: rio-0.1.9.2-72TcXYNB0GwDfO1W7KeLOh
key: rio-0.1.9.2-72TcXYNB0GwDfO1W7KeLOh
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/rio#readme
synopsis: A standard library for Haskell
description:
    See README and Haddocks at <https://www.stackage.org/package/rio>
category: Control
abi: e9415478e4279be71cdc06f13fc5298a
exposed: True
exposed-modules:
    RIO RIO.ByteString RIO.ByteString.Lazy RIO.ByteString.Lazy.Partial
    RIO.ByteString.Partial RIO.Char RIO.Char.Partial RIO.Deque
    RIO.Directory RIO.File RIO.FilePath RIO.HashMap RIO.HashMap.Partial
    RIO.HashSet RIO.List RIO.List.Partial RIO.Map RIO.Map.Partial
    RIO.Map.Unchecked RIO.Partial RIO.Prelude RIO.Prelude.Simple
    RIO.Prelude.Types RIO.Process RIO.Seq RIO.Set RIO.Set.Partial
    RIO.Set.Unchecked RIO.State RIO.Text RIO.Text.Lazy
    RIO.Text.Lazy.Partial RIO.Text.Partial RIO.Time RIO.Vector
    RIO.Vector.Boxed RIO.Vector.Boxed.Partial RIO.Vector.Boxed.Unsafe
    RIO.Vector.Partial RIO.Vector.Storable RIO.Vector.Storable.Partial
    RIO.Vector.Storable.Unsafe RIO.Vector.Unboxed
    RIO.Vector.Unboxed.Partial RIO.Vector.Unboxed.Unsafe
    RIO.Vector.Unsafe RIO.Writer
hidden-modules: RIO.Prelude.Display RIO.Prelude.Exit
                RIO.Prelude.Extra RIO.Prelude.IO RIO.Prelude.Lens
                RIO.Prelude.Logger RIO.Prelude.Reexports RIO.Prelude.Renames
                RIO.Prelude.RIO RIO.Prelude.Text RIO.Prelude.Trace RIO.Prelude.URef
import-dirs: /usr/lib/ghc-8.6.5/site-local/rio-0.1.9.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/rio-0.1.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/rio-0.1.9.2
hs-libraries: HSrio-0.1.9.2-72TcXYNB0GwDfO1W7KeLOh
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    deepseq-1.4.4.0 directory-1.3.3.0
    exceptions-0.10.2-EJs0RkZsum56ksbfDqbl1F filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS mtl-2.2.2
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b process-1.6.5.0
    text-1.2.3.1 time-1.8.0.2
    typed-process-0.2.4.1-beWb2K35BN9E1vzafS6o7 unix-2.7.2.2
    unliftio-0.2.11-HfZ36uDuQPe4HzZMREy7XZ
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-FCaPs5fnhYpFgvItTiMoQE
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-rio/html/rio.haddock
haddock-html: /usr/share/doc/haskell-rio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
